Python-like API for Unity YAML parsing
This module provides a more Python-like interface similar to the reference library, making it easier for users familiar with the Python unity-yaml-parser to migrate.
Structs
- Python
Like Unity Class - Python-like wrapper for Unity classes
- Python
Like Unity Class Mut - Mutable Python-like wrapper for Unity classes
- Python
Like Unity Document - Python-like wrapper for Unity documents